@@ -1,21 +1,8 @@
-/******************************************************************************
-*   Copyright 2007 by Bertjan Broeksema <b.broeksema@kdemail.net>             *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Bertjan Broeksema <b.broeksema@kdemail.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "plasmoidpackagetest.h"
 #include "../src/kpackage/config-package.h"
@@ -24,8 +11,9 @@
 #include <QDir>
 #include <QFile>
 #include <kzip.h>
-#include <kjob.h>
+#include <KJob>
 #include <QStandardPaths>
+#include <QSignalSpy>
 
 #include <QDebug>
 
@@ -35,7 +23,7 @@
 
 void PlasmoidPackageTest::initTestCase()
 {
-    QStandardPaths::enableTestMode(true);
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 void PlasmoidPackageTest::init()
@@ -70,7 +58,7 @@ void PlasmoidPackageTest::createTestPackage(const QString &packageName, const QS
     // Create the metadata.desktop file
     QFile file(m_packageRoot + "/" + packageName + "/metadata.desktop");
 
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     QTextStream out(&file);
     out << "[Desktop Entry]\n";
@@ -87,7 +75,7 @@ void PlasmoidPackageTest::createTestPackage(const QString &packageName, const QS
 
     // Create the main file.
     file.setFileName(m_packageRoot + "/" + packageName + "/contents/ui/main.qml");
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     out << "THIS IS A PLASMOID SCRIPT.....";
     file.flush();
@@ -101,7 +89,7 @@ void PlasmoidPackageTest::createTestPackage(const QString &packageName, const QS
     QVERIFY(QDir().mkpath(m_packageRoot + "/" + packageName + "/contents/images"));
     file.setFileName(m_packageRoot + "/" + packageName + "/contents/images/image-1.svg");
 
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     out << "<svg>This is a test image</svg>";
     file.flush();
@@ -109,7 +97,7 @@ void PlasmoidPackageTest::createTestPackage(const QString &packageName, const QS
 
     file.setFileName(m_packageRoot + "/" + packageName + "/contents/images/image-2.svg");
 
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     out.setDevice(&file);
     out << "<svg>This is another test image</svg>";
@@ -121,7 +109,7 @@ void PlasmoidPackageTest::createTestPackage(const QString &packageName, const QS
 
     // Create 2 js files
     file.setFileName(m_packageRoot + "/" + packageName + "/contents/code/script.js");
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     out << "THIS IS A SCRIPT.....";
     file.flush();
@@ -153,7 +141,7 @@ void PlasmoidPackageTest::isValid()
 
     // Create the metadata.desktop file.
     QFile file(m_packageRoot + "/" + m_package + "/metadata.desktop");
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     QTextStream out(&file);
     out << "[Desktop Entry]\n";
@@ -173,7 +161,7 @@ void PlasmoidPackageTest::isValid()
 
     // Create the main file.
     file.setFileName(m_packageRoot + "/" + m_package + "/contents/ui/main.qml");
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     out.setDevice(&file);
     out << "THIS IS A PLASMOID SCRIPT.....\n";
@@ -186,11 +174,9 @@ void PlasmoidPackageTest::isValid()
     p = new KPackage::Package(m_defaultPackage);
     p->setPath(m_packageRoot + '/' + m_package);
     QVERIFY(p->isValid());
-    // Ignore deprecation warning, we are actually testing this here.
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#if KPACKAGE_ENABLE_DEPRECATED_SINCE(5, 21)
     QCOMPARE(p->contentsHash(), QStringLiteral("a41160c6a763ea505c95bee12a7fc87952a61cf1"));
-#pragma GCC diagnostic pop
+#endif
     QCOMPARE(p->cryptographicHash(QCryptographicHash::Sha1), QByteArrayLiteral("a41160c6a763ea505c95bee12a7fc87952a61cf1"));
     delete p;
 }
@@ -208,7 +194,7 @@ void PlasmoidPackageTest::filePath()
 
     QVERIFY(QDir().mkpath(m_packageRoot + "/" + m_package + "/contents/ui/main.qml"));
     QFile file(m_packageRoot + "/" + m_package + "/contents/ui/main.qml");
-    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    QVERIFY(file.open(QIODevice::WriteOnly));
 
     QTextStream out(&file);
     out << "THIS IS A PLASMOID SCRIPT.....";
@@ -435,14 +421,12 @@ void PlasmoidPackageTest::cleanupPackage(const QString &packageName)
 
 void PlasmoidPackageTest::packageInstalled(KJob *j)
 {
-    qDebug() << "!!!!!!!!!!!!!!!!!!!! package installed" << (j->error() == KJob::NoError) << j->errorText();
-    QVERIFY(j->error() == KJob::NoError);
+    QVERIFY2(j->error() == KJob::NoError, qPrintable(j->errorText()));
 }
 
 void PlasmoidPackageTest::packageUninstalled(KJob *j)
 {
-    qDebug() << "!!!!!!!!!!!!!!!!!!!!! package uninstalled";
-    QVERIFY(j->error() == KJob::NoError);
+    QVERIFY2(j->error() == KJob::NoError, qPrintable(j->errorText()));
 }
 
 QTEST_MAIN(PlasmoidPackageTest)
