@@ -1,41 +1,27 @@
-/******************************************************************************
-*   Copyright 2007 by Aaron Seigo <aseigo@kde.org>                            *
-*   Copyright 2010 by Marco Martin <notmart@gmail.com>                        *
-*   Copyright 2010 by Kevin Ottens <ervin@kde.org>                            *
-*   Copyright 2009 by Rob Scheepmaker                                         *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2010 Marco Martin <notmart@gmail.com>
+    SPDX-FileCopyrightText: 2010 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Rob Scheepmaker
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "package.h"
 
 #include <qtemporarydir.h>
 #include <QResource>
 
-#include <karchive.h>
+#include <KArchive>
 #include "kpackage_debug.h"
-#include <QUrl>
-#include <ktar.h>
+#include <KTar>
 #include <kzip.h>
 #include <KLocalizedString>
 
 #include "config-package.h"
 
-#include <qstandardpaths.h>
-#include <qmimedatabase.h>
+#include <QStandardPaths>
+#include <QMimeDatabase>
 
 #include "packagestructure.h"
 #include "packageloader.h"
@@ -627,7 +613,7 @@ void Package::setContentsPrefixPaths(const QStringList &prefixPaths)
     }
 }
 
-#ifndef PACKAGE_NO_DEPRECATED
+#if KPACKAGE_BUILD_DEPRECATED_SINCE(5, 21)
 QString Package::contentsHash() const
 {
     return QString::fromLocal8Bit(cryptographicHash(QCryptographicHash::Sha1));
@@ -820,7 +806,12 @@ QList<QByteArray> Package::requiredFiles() const
 
 KJob *Package::install(const QString &sourcePackage, const QString &packageRoot)
 {
+    if (!d->structure) {
+        return nullptr;
+    }
+
     const QString src = sourcePackage;
+    setPath(src);
     QString dest = packageRoot.isEmpty() ? defaultPackageRoot() : packageRoot;
     KPackage::PackageLoader::self()->d->maxCacheAge = -1;
 
@@ -829,9 +820,6 @@ KJob *Package::install(const QString &sourcePackage, const QString &packageRoot)
         dest = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + dest;
     }
 
-    if (!d->structure) {
-        return nullptr;
-    }
     //qCDebug(KPACKAGE_LOG) << "Source: " << src;
     //qCDebug(KPACKAGE_LOG) << "PackageRoot: " << dest;
     KJob *j = d->structure.data()->install(this, src, dest);
@@ -840,18 +828,20 @@ KJob *Package::install(const QString &sourcePackage, const QString &packageRoot)
 
 KJob *Package::update(const QString &sourcePackage, const QString &packageRoot)
 {
+    if (!d->structure) {
+        return nullptr;
+    }
+
     const QString src = sourcePackage;
+    setPath(src);
     QString dest = packageRoot.isEmpty() ? defaultPackageRoot() : packageRoot;
-     KPackage::PackageLoader::self()->d->maxCacheAge = -1;
+    KPackage::PackageLoader::self()->d->maxCacheAge = -1;
 
     //use absolute paths if passed, otherwise go under share
     if (!QDir::isAbsolutePath(dest)) {
         dest = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + dest;
     }
 
-    if (!d->structure) {
-        return nullptr;
-    }
     //qCDebug(KPACKAGE_LOG) << "Source: " << src;
     //qCDebug(KPACKAGE_LOG) << "PackageRoot: " << dest;
     KJob *j = d->structure.data()->update(this, src, dest);
@@ -860,7 +850,7 @@ KJob *Package::update(const QString &sourcePackage, const QString &packageRoot)
 
 KJob *Package::uninstall(const QString &packageName, const QString &packageRoot)
 {
-     KPackage::PackageLoader::self()->d->maxCacheAge = -1;
+    KPackage::PackageLoader::self()->d->maxCacheAge = -1;
     d->createPackageMetadata(packageRoot + QLatin1Char('/') + packageName);
     if (!d->structure) {
         return nullptr;
@@ -993,7 +983,7 @@ void PackagePrivate::createPackageMetadata(const QString &path)
         metadata = new KPluginMetaData(md);
     } else {
         if (isDir) {
-            qCWarning(KPACKAGE_LOG) << "No metadata file in the package, expected it at:" << path;
+            qCDebug(KPACKAGE_LOG) << "No metadata file in the package, expected it at:" << path;
         } else if (path.endsWith(QLatin1String(".desktop"))) {
             auto md = KPluginMetaData::fromDesktopFile(path, {QStringLiteral(":/kservicetypes5/kpackage-generic.desktop")});
             metadata = new KPluginMetaData(md);
