@@ -1,39 +1,26 @@
-/******************************************************************************
-*   Copyright 2008 Aaron Seigo <aseigo@kde.org>                               *
-*   Copyright 2012-2017 Sebastian Kügler <sebas@kde.org>                      *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2012-2017 Sebastian Kügler <sebas@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kpackagetool.h"
 
 #include <QDebug>
 #include <QJsonDocument>
 #include <QJsonArray>
-#include <kshell.h>
-#include <klocalizedstring.h>
-#include <kaboutdata.h>
+#include <KShell>
+#include <KLocalizedString>
+#include <KAboutData>
 #include <KPluginLoader>
 
 #include <kpackage/packagestructure.h>
 #include <kpackage/package.h>
 #include <kpackage/packageloader.h>
-#include <kjob.h>
+#include <KJob>
 
-#include <qcommandlineparser.h>
+#include <QCommandLineParser>
 #include <QDir>
 #include <QDirIterator>
 #include <QFileInfo>
@@ -63,7 +50,8 @@ static QVector<KPluginMetaData> listPackageTypes()
 
     const QString subDirectory = QStringLiteral("kpackage/packagestructure");
 
-    Q_FOREACH (const QString &dir, QCoreApplication::libraryPaths()) {
+    const auto lstPath = QCoreApplication::libraryPaths();
+    for (const QString &dir : lstPath) {
         QString d = dir + QDir::separator() + subDirectory;
         if (!d.endsWith(QDir::separator())) {
             d += QDir::separator();
@@ -72,7 +60,7 @@ static QVector<KPluginMetaData> listPackageTypes()
     }
 
     QVector<KPluginMetaData> offers;
-    Q_FOREACH (const QString &plugindir, libraryPaths) {
+    for (const QString &plugindir : qAsConst(libraryPaths)) {
         const QString &_ixfile = plugindir + s_kpluginindex;
         QFile indexFile(_ixfile);
         if (indexFile.exists()) {
@@ -116,7 +104,7 @@ public:
     void listTypes();
     void coutput(const QString &msg);
     void cerror(const QString &msg);
-    QCommandLineParser *parser;
+    QCommandLineParser *parser = nullptr;
 };
 
 PackageTool::PackageTool(int &argc, char **argv, QCommandLineParser *parser) :
@@ -124,7 +112,7 @@ PackageTool::PackageTool(int &argc, char **argv, QCommandLineParser *parser) :
 {
     d = new PackageToolPrivate;
     d->parser = parser;
-    QTimer::singleShot(0, this, SLOT(runMain()));
+    QTimer::singleShot(0, this, &PackageTool::runMain);
 }
 
 PackageTool::~PackageTool()
@@ -135,8 +123,8 @@ PackageTool::~PackageTool()
 void PackageTool::runMain()
 {
     KPackage::PackageStructure structure;
-    if (d->parser->isSet(Options::hash)) {
-        const QString path = d->parser->value(Options::hash);
+    if (d->parser->isSet(Options::hash())) {
+        const QString path = d->parser->value(Options::hash());
         KPackage::Package package(&structure);
         package.setPath(path);
         const QString hash =
@@ -151,39 +139,39 @@ void PackageTool::runMain()
         return;
     }
 
-    if (d->parser->isSet(Options::listTypes)) {
+    if (d->parser->isSet(Options::listTypes())) {
         d->listTypes();
         exit(0);
         return;
     }
 
-    QString type = d->parser->value(Options::type);
+    QString type = d->parser->value(Options::type());
     d->pluginTypes.clear();
     d->installer = Package();
 
-    if (d->parser->isSet(Options::remove)) {
-        d->package = d->parser->value(Options::remove);
-    } else if (d->parser->isSet(Options::upgrade)) {
-        d->package = d->parser->value(Options::upgrade);
-    } else if (d->parser->isSet(Options::install)) {
-        d->package = d->parser->value(Options::install);
-    } else if (d->parser->isSet(Options::show)) {
-        d->package = d->parser->value(Options::show);
-    } else if (d->parser->isSet(Options::appstream)) {
-        d->package = d->parser->value(Options::appstream);
+    if (d->parser->isSet(Options::remove())) {
+        d->package = d->parser->value(Options::remove());
+    } else if (d->parser->isSet(Options::upgrade())) {
+        d->package = d->parser->value(Options::upgrade());
+    } else if (d->parser->isSet(Options::install())) {
+        d->package = d->parser->value(Options::install());
+    } else if (d->parser->isSet(Options::show())) {
+        d->package = d->parser->value(Options::show());
+    } else if (d->parser->isSet(Options::appstream())) {
+        d->package = d->parser->value(Options::appstream());
     }
 
     if (!QDir::isAbsolutePath(d->package)) {
         d->packageFile = QDir(QDir::currentPath() + QLatin1Char('/') + d->package).absolutePath();
         d->packageFile = QFileInfo(d->packageFile).canonicalFilePath();
-        if (d->parser->isSet(Options::upgrade)) {
+        if (d->parser->isSet(Options::upgrade())) {
             d->package = d->packageFile;
         }
     } else {
         d->packageFile = d->package;
     }
 
-    if (!d->packageFile.isEmpty() && (!d->parser->isSet(Options::type) ||
+    if (!d->packageFile.isEmpty() && (!d->parser->isSet(Options::type()) ||
                                       type.compare(i18nc("package type", "wallpaper"), Qt::CaseInsensitive) == 0 ||
                                       type.compare(QLatin1String("wallpaper"), Qt::CaseInsensitive) == 0)) {
         // Check type for common plasma packages
@@ -222,27 +210,27 @@ void PackageTool::runMain()
         d->packageRoot = d->installer.defaultPackageRoot();
         d->pluginTypes << type;
     }
-    if (d->parser->isSet(Options::show)) {
+    if (d->parser->isSet(Options::show())) {
         const QString pluginName = d->package;
         showPackageInfo(pluginName);
         return;
-    } else if (d->parser->isSet(Options::appstream)) {
+    } else if (d->parser->isSet(Options::appstream())) {
         const QString pluginName = d->package;
         showAppstreamInfo(pluginName);
         return;
     }
 
-    if (d->parser->isSet(Options::list)) {
+    if (d->parser->isSet(Options::list())) {
         d->packageRoot = findPackageRoot(d->package, d->packageRoot);
         d->coutput(i18n("Listing service types: %1 in %2", d->pluginTypes.join(QStringLiteral(", ")), d->packageRoot));
         listPackages(d->pluginTypes, d->packageRoot);
         exit(0);
 
-    } else if (d->parser->isSet(Options::generateIndex)) {
+    } else if (d->parser->isSet(Options::generateIndex())) {
         recreateIndex();
         exit(0);
 
-    } else if (d->parser->isSet(Options::removeIndex)) {
+    } else if (d->parser->isSet(Options::removeIndex())) {
         removeIndex();
         exit(0);
 
@@ -255,9 +243,9 @@ void PackageTool::runMain()
 
         d->packageRoot = findPackageRoot(d->package, d->packageRoot);
 
-        if (d->parser->isSet(Options::remove) || d->parser->isSet(Options::upgrade)) {
+        if (d->parser->isSet(Options::remove()) || d->parser->isSet(Options::upgrade())) {
             QString pkgPath;
-            foreach (const QString &t, d->pluginTypes) {
+            for (const QString &t : qAsConst(d->pluginTypes)) {
                 KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(t);
                 pkg.setPath(d->package);
                 if (pkg.isValid()) {
@@ -272,7 +260,7 @@ void PackageTool::runMain()
                 pkgPath = d->package;
             }
 
-            if (d->parser->isSet(Options::upgrade)) {
+            if (d->parser->isSet(Options::upgrade())) {
                 d->installer.setPath(d->package);
             }
             QString _p = d->packageRoot;
@@ -283,8 +271,9 @@ void PackageTool::runMain()
             d->installer.setDefaultPackageRoot(d->packageRoot);
             d->installer.setPath(pkgPath);
 
-            if (!d->parser->isSet(Options::type)) {
-                foreach (const QString &st, d->installer.metadata().serviceTypes()) {
+            if (!d->parser->isSet(Options::type())) {
+                const auto lst = d->installer.metadata().serviceTypes();
+                for (const QString &st : lst) {
                     if (!d->pluginTypes.contains(st)) {
                         d->pluginTypes << st;
                     }
@@ -325,7 +314,7 @@ void PackageTool::runMain()
                 exit(2);
             }
         }
-        if (d->parser->isSet(Options::install)) {
+        if (d->parser->isSet(Options::install())) {
             KJob *installJob = d->installer.install(d->packageFile, d->packageRoot);
             connect(installJob, SIGNAL(result(KJob*)), SLOT(packageInstalled(KJob*)));
             return;
@@ -339,21 +328,23 @@ void PackageTool::runMain()
 
 void PackageToolPrivate::coutput(const QString &msg)
 {
-    *cout << msg << endl;
+    *cout << msg << '\n';
+    (*cout).flush();
 }
 
 void PackageToolPrivate::cerror(const QString &msg)
 {
-    *cerr << msg << endl;
+    *cerr << msg << '\n';
+    (*cerr).flush();
 }
 
 QStringList PackageToolPrivate::packages(const QStringList &types, const QString &path)
 {
     QStringList result;
 
-    foreach (const QString &type, types) {
+    for (const QString &type : types) {
         const QList<KPluginMetaData> services = KPackage::PackageLoader::self()->listPackages(type, path);
-        foreach (const KPluginMetaData &service, services) {
+        for (const KPluginMetaData &service : services) {
             const QString _plugin = service.pluginId();
             if (!result.contains(_plugin)) {
                 result << _plugin;
@@ -431,12 +422,11 @@ bool translateKPluginToAppstream(const QString &tagName, const QString &configFi
 void PackageTool::showAppstreamInfo(const QString &pluginName)
 {
     KPluginMetaData i;
-    KPluginMetaData packageStructureMetaData;
     //if the path passed is an absolute path, and a metadata file is found under it, use that metadata file to generate the appstream info.
     // This can happen in the case an application wanting to support kpackage based extensions includes in the same project both the packagestructure plugin and the packages themselves. In that case at build time the packagestructure plugin wouldn't be installed yet
 
     if (QFile::exists(pluginName + QStringLiteral("/metadata.desktop"))) {
-        i = KPluginMetaData(pluginName + QStringLiteral("/metadata.desktop"));
+        i = KPluginMetaData::fromDesktopFile(pluginName + QStringLiteral("/metadata.desktop"), {QStringLiteral(":/kservicetypes5/kpackage-generic.desktop")});
     } else if (QFile::exists(pluginName + QStringLiteral("/metadata.json"))) {
         i = KPluginMetaData(pluginName + QStringLiteral("/metadata.json"));
     } else {
@@ -454,16 +444,26 @@ void PackageTool::showAppstreamInfo(const QString &pluginName)
             pkg.setPath(pluginName);
         }
 
-        {
-            foreach(const KPluginMetaData &md, listPackageTypes()) {
-                if (md.pluginId() == type) {
-                    packageStructureMetaData = md;
-                    break;
-                }
-            }
+        i = pkg.metadata();
+    }
+
+    KPluginMetaData packageStructureMetaData;
+    {
+        const auto lst = listPackageTypes();
+
+        QString type;
+        if (!i.serviceTypes().isEmpty()) {
+            type = i.serviceTypes().constFirst();
+        } else {
+            type = QStringLiteral("KPackage/Generic");
         }
 
-        i = pkg.metadata();
+        for (const KPluginMetaData &md : lst) {
+            if (md.pluginId() == type) {
+                packageStructureMetaData = md;
+                break;
+            }
+        }
     }
 
     if (!i.isValid()) {
@@ -499,7 +499,7 @@ void PackageTool::showAppstreamInfo(const QString &pluginName)
     // TODO: in KF6 we should switch to argument-only.
     QIODevice *outputDevice = cout->device();
     QScopedPointer<QFile> outputFile;
-    const auto outputPath = d->parser->value(Options::appstreamOutput);
+    const auto outputPath = d->parser->value(Options::appstreamOutput());
     if (!outputPath.isEmpty()) {
         auto outputUrl = QUrl::fromUserInput(outputPath);
         outputFile.reset(new QFile(outputUrl.toLocalFile()));
@@ -570,13 +570,13 @@ QString PackageTool::findPackageRoot(const QString &pluginName, const QString &p
     Q_UNUSED(pluginName);
     Q_UNUSED(prefix);
     QString packageRoot;
-    if (d->parser->isSet(Options::packageRoot) && d->parser->isSet(Options::global) && !d->parser->isSet(Options::generateIndex)) {
+    if (d->parser->isSet(Options::packageRoot()) && d->parser->isSet(Options::global()) && !d->parser->isSet(Options::generateIndex())) {
         qWarning() << i18nc("The user entered conflicting options packageroot and global, this is the error message telling the user he can use only one", "The packageroot and global options conflict with each other, please select only one.");
         ::exit(7);
-    } else if (d->parser->isSet(Options::packageRoot)) {
-        packageRoot = d->parser->value(Options::packageRoot);
+    } else if (d->parser->isSet(Options::packageRoot())) {
+        packageRoot = d->parser->value(Options::packageRoot());
         //qDebug() << "(set via arg) d->packageRoot is: " << d->packageRoot;
-    } else if (d->parser->isSet(Options::global)) {
+    } else if (d->parser->isSet(Options::global())) {
         auto const paths = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, d->packageRoot, QStandardPaths::LocateDirectory);
         if (!paths.isEmpty()) {
             packageRoot = paths.last();
@@ -591,7 +591,7 @@ void PackageTool::listPackages(const QStringList &types, const QString &path)
 {
     QStringList list = d->packages(types, path);
     list.sort();
-    foreach (const QString &package, list) {
+    for (const QString &package : qAsConst(list)) {
         d->coutput(package);
     }
     exit(0);
@@ -660,7 +660,7 @@ void PackageToolPrivate::listTypes()
         coutput(i18n("Provided by plugins:"));
 
         QMap<QString, QStringList> plugins;
-        foreach (const KPluginMetaData &info, offers) {
+        for (const KPluginMetaData &info : offers) {
             KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(info.pluginId());
             QString name = info.name();
             QString plugin = info.pluginId();
@@ -677,13 +677,13 @@ void PackageTool::recreateIndex()
     d->packageRoot = findPackageRoot(d->package, d->packageRoot);
 
     if (!QDir::isAbsolutePath(d->packageRoot)) {
-        if (d->parser->isSet(Options::global)) {
+        if (d->parser->isSet(Options::global())) {
 
             // Find package roots
             QStringList packageRoots;
             const QVector<KPluginMetaData> offers = listPackageTypes();
             if (!offers.isEmpty()) {
-                foreach (const KPluginMetaData &info, offers) {
+                for (const KPluginMetaData &info : offers) {
                     KPackage::Package pkg = KPackage::PackageLoader::self()->loadPackage(info.pluginId());
                     const auto proot = pkg.defaultPackageRoot();
                     if (!proot.isEmpty()) {
@@ -691,8 +691,8 @@ void PackageTool::recreateIndex()
                     }
                 }
             }
-
-            Q_FOREACH(auto const &p, QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, d->packageRoot, QStandardPaths::LocateDirectory)) {
+            const auto lstPath = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, d->packageRoot, QStandardPaths::LocateDirectory);
+            for (auto const &p : lstPath) {
                 for (const auto &_proot: qAsConst(packageRoots)) {
                     QFileInfo packageDirInfo(QStringLiteral("%1%2").arg(p, _proot));
                     if (!packageDirInfo.isWritable()) {
@@ -724,8 +724,9 @@ void PackageTool::removeIndex()
     d->packageRoot = findPackageRoot(d->package, d->packageRoot);
 
     if (!QDir::isAbsolutePath(d->packageRoot)) {
-        if (d->parser->isSet(Options::global)) {
-            Q_FOREACH(auto const &p, QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, d->packageRoot, QStandardPaths::LocateDirectory)) {
+        if (d->parser->isSet(Options::global())) {
+            const auto lstEntries = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, d->packageRoot, QStandardPaths::LocateDirectory);
+            for (auto const &p : lstEntries) {
                 QDirIterator it(p, QStringList(s_kpluginindex), QDir::Files | QDir::Writable | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
                 qDebug() << "IX index remove" << p;
                 while (it.hasNext()) {
@@ -759,7 +760,7 @@ void PackageTool::packageInstalled(KJob *job)
     bool success = (job->error() == KJob::NoError);
     int exitcode = 0;
     if (success) {
-        if (d->parser->isSet(Options::upgrade)) {
+        if (d->parser->isSet(Options::upgrade())) {
             d->coutput(i18n("Successfully upgraded %1", d->packageFile));
         } else {
             d->coutput(i18n("Successfully installed %1", d->packageFile));
@@ -776,7 +777,7 @@ void PackageTool::packageUninstalled(KJob *job)
     bool success = (job->error() == KJob::NoError);
     int exitcode = 0;
     if (success) {
-        if (d->parser->isSet(Options::upgrade)) {
+        if (d->parser->isSet(Options::upgrade())) {
             d->coutput(i18n("Upgrading package from file: %1", d->packageFile));
             KJob *installJob = d->installer.install(d->packageFile, d->packageRoot);
             connect(installJob, SIGNAL(result(KJob*)), SLOT(packageInstalled(KJob*)));
